@@ -1,8 +1,8 @@
 #include "vtkDICOMMetaData.h"
 #include "vtkDICOMFileSorter.h"
 
-#include <vtkSmartPointer.h>
-#include <vtkStringArray.h>
+#include "vtkSmartPointer.h"
+#include "vtkStringArray.h"
 
 #include <sstream>
 
