@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -46,7 +46,7 @@ void dicompull_version(FILE *file, const char *cp)
 {
   fprintf(file, "%s %s\n", cp, DICOM_VERSION);
   fprintf(file, "\n"
-    "Copyright (c) 2012-2019, David Gobbi.\n\n"
+    "Copyright (c) 2012-2022, David Gobbi.\n\n"
     "This software is distributed under an open-source license.  See the\n"
     "Copyright.txt file that comes with the vtk-dicom source distribution.\n");
 }
@@ -67,6 +67,7 @@ void dicompull_usage(FILE *file, const char *cp)
     "  -name pattern     Set file names to match (with \"*\" or \"?\").\n"
     "  -image            Restrict the search to files with PixelData.\n"
     "  -series           Find all files in series if even one file matches.\n"
+    "  --directory-only  Do not scan files for search if DICOMDIR is present.\n"
     "  --ignore-dicomdir Ignore the DICOMDIR file even if it is present.\n"
     "  --charset <cs>    Charset to use if SpecificCharacterSet is missing.\n"
     "  --silent          Do not report any progress information.\n"
@@ -85,7 +86,7 @@ void dicompull_help(FILE *file, const char *cp)
     "The output directory given with \"-o\" can use DICOM attributes, by\n"
     "naming those attributes within curly braces.  For example, consider\n"
     "\"{PatientID}/{StudyDescription}/{SeriesDescription}-{SeriesNumber}\"\n"
-    "or something similar to produce a hierarchichal directory structure.\n"
+    "or something similar to produce a hierarchical directory structure.\n"
     "\n"
     "The files to be copied are specified with search keys, which take the\n"
     "form \"-k key=value\" where keys can either use the standard names given\n"
@@ -307,6 +308,7 @@ int MAINMACRO(int argc, char *argv[])
   vtkDICOMItem query;
   bool requirePixelData = false;
   bool findSeries = false;
+  bool onlyDicomdir = false;
   bool ignoreDicomdir = false;
   vtkDICOMCharacterSet charset;
   bool silent = false;
@@ -433,6 +435,10 @@ int MAINMACRO(int argc, char *argv[])
     {
       findSeries = true;
     }
+    else if (strcmp(arg, "--directory-only") == 0)
+    {
+      onlyDicomdir = true;
+    }
     else if (strcmp(arg, "--ignore-dicomdir") == 0)
     {
       ignoreDicomdir = true;
@@ -551,6 +557,10 @@ int MAINMACRO(int argc, char *argv[])
     finder->SetScanDepth(scandepth);
     finder->SetFindQuery(query);
     finder->SetIgnoreDicomdir(ignoreDicomdir);
+    if (onlyDicomdir)
+    {
+      finder->SetQueryFilesToNever();
+    }
     finder->SetFollowSymlinks(followSymlinks);
     finder->SetRequirePixelData(requirePixelData);
     finder->SetFindLevel(
