@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -35,7 +35,7 @@ void printVersion(FILE *file, const char *cp)
 {
   fprintf(file, "%s %s\n", cp, DICOM_VERSION);
   fprintf(file, "\n"
-    "Copyright (c) 2012-2019, David Gobbi.\n\n"
+    "Copyright (c) 2012-2022, David Gobbi.\n\n"
     "This software is distributed under an open-source license.  See the\n"
     "Copyright.txt file that comes with the vtk-dicom source distribution.\n");
 }
@@ -71,7 +71,7 @@ const char *stringSanitize(
   size_t i;
   for (i = 0; i < l && cp[i] != '\0'; i++)
   {
-    if (isprint(cp[i]))
+    if (isprint(static_cast<unsigned char>(cp[i])))
     {
       op[i] = cp[i];
     }
