@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -28,9 +28,19 @@
 #include "vtkDICOMModule.h" // For export macro
 #include "vtkDICOMConfig.h" // For configuration details
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkLookupTable;
 class vtkInformationDataObjectKey;
 class vtkInformationDoubleVectorKey;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkDICOMMetaData;
 class vtkDICOMPerFilePalette;
 
@@ -58,7 +68,7 @@ public:
 
 protected:
   vtkDICOMAlgorithm();
-  ~vtkDICOMAlgorithm();
+  ~vtkDICOMAlgorithm() VTK_DICOM_OVERRIDE;
 
   //@{
   //! Get the information object that holds the meta data for the given input.
