@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -26,8 +26,17 @@
 #include "vtkDICOMAlgorithm.h"
 #include "vtkDICOMModule.h" // For export macro
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkMatrix4x4;
 
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 //----------------------------------------------------------------------------
 class VTKDICOM_EXPORT vtkDICOMCTRectifier : public vtkDICOMAlgorithm
 {
@@ -121,7 +130,7 @@ public:
 
 protected:
   vtkDICOMCTRectifier();
-  ~vtkDICOMCTRectifier();
+  ~vtkDICOMCTRectifier() VTK_DICOM_OVERRIDE;
 
   //! Compute the rectified matrix from the given volume matrix.
   /*!
