@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -20,8 +20,18 @@
 #include "vtkDICOMCharacterSet.h" // For character sets
 #include "vtkVersion.h" // For changes to pipeline API
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkStringArray;
 class vtkIntArray;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkDICOMMetaData;
 class vtkDICOMItem;
 class vtkDICOMTag;
@@ -278,7 +288,7 @@ public:
 
 protected:
   vtkDICOMDirectory();
-  ~vtkDICOMDirectory();
+  ~vtkDICOMDirectory() VTK_DICOM_OVERRIDE;
 
   const char *DirectoryName;
   vtkStringArray *InputFileNames;
