@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -18,8 +18,18 @@
 #include "vtkDICOMModule.h" // For export macro
 #include "vtkDICOMConfig.h" // For configuration details
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkStringArray;
 class vtkIntArray;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkDICOMMetaData;
 
 //! Sort DICOM files and group them by study and series.
@@ -110,7 +120,7 @@ public:
 
 protected:
   vtkDICOMFileSorter();
-  ~vtkDICOMFileSorter();
+  ~vtkDICOMFileSorter() VTK_DICOM_OVERRIDE;
 
   const char *InputFileName;
   vtkStringArray *InputFileNames;
