@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -20,10 +20,20 @@
 #include "vtkDICOMConfig.h" // For configuration details
 #include "vtkDICOMTag.h" // For method parameter
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkIntArray;
 class vtkMatrix4x4;
 class vtkInformation;
 class vtkStringArray;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkDICOMMetaData;
 class vtkDICOMItem;
 class vtkDICOMUIDGenerator;
@@ -242,7 +252,7 @@ protected:
   //@{
   //! Protected constructor method.
   vtkDICOMGenerator();
-  ~vtkDICOMGenerator();
+  ~vtkDICOMGenerator() VTK_DICOM_OVERRIDE;
   //@}
 
   //@{
@@ -350,7 +360,7 @@ protected:
     const DC::EnumType *tags, vtkDICOMMetaData *source);
   //@}
 
-  //! Copy all atributes into the meta data, excluding blacklisted ones.
+  //! Copy all attributes into the meta data, excluding blacklisted ones.
   /*!
    *  The blacklist must be terminated with DC::ItemDelimitationItem.
    *  The blacklist may be set to NULL.
