@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -58,7 +58,7 @@ public:
 
 protected:
   vtkDICOMLookupTable();
-  ~vtkDICOMLookupTable();
+  ~vtkDICOMLookupTable() VTK_DICOM_OVERRIDE;
 
   //! Build a lookup table from compressed data.
   /*!
