@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -21,7 +21,17 @@
 #include "vtkDICOMDataElement.h" // For method parameter
 #include "vtkDICOMDictEntry.h" // For method parameter
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkIntArray;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkDICOMTagPath;
 
 //! A container class for DICOM metadata.
@@ -330,7 +340,7 @@ public:
 
 protected:
   vtkDICOMMetaData();
-  ~vtkDICOMMetaData();
+  ~vtkDICOMMetaData() VTK_DICOM_OVERRIDE;
 
   //! Find a tag, value pair.
   vtkDICOMDataElement *FindDataElement(vtkDICOMTag tag);
