@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -25,6 +25,7 @@
 #include <ctype.h>
 #include <assert.h>
 
+#include <sstream>
 #include <string>
 #include <vector>
 #include <algorithm>
@@ -147,9 +148,11 @@ public:
 
   // Get the current item.
   vtkDICOMItem *GetItem() { return this->Item; }
+  int GetIndex() { return this->Index; }
 
   // Set the current tag position for the context.
   void SetCurrentTag(vtkDICOMTag tag) { this->CurrentTag = tag; }
+  vtkDICOMTag GetCurrentTag() { return this->CurrentTag; }
 
 private:
   DecoderContext *Prev;
@@ -342,6 +345,10 @@ public:
   // If there are fewer than "n" bytes left in the buffer, then move
   // any data that hasn't yet been parsed to the start of the buffer,
   // and then read new data into the remainder of the buffer.
+  // A return value of "false" indicates that the check failed
+  // because the needed bytes could not be read from the file, either
+  // due to an IO error or the end of the file. If "false" is
+  // returned, "cp" will be advanced to the position of "ep".
   bool CheckBuffer(
     const unsigned char* &cp, const unsigned char* &ep, size_t n);
 
@@ -390,6 +397,10 @@ public:
   // Finish the query (check for unused keys that must match).
   bool FinishQuery();
 
+  // Report an error.
+  void ParseError(
+    const unsigned char *cp, const unsigned char *ep, const char *message);
+
 protected:
   // Constructor that initializes all of the members.
   DecoderBase(vtkDICOMParser *parser, vtkDICOMMetaData *data, int idx) :
@@ -651,9 +662,12 @@ inline bool DecoderBase::CheckBuffer(
   bool r = true;
   if (n > static_cast<size_t>(ep - cp))
   {
-    r = vtkDICOMParserInternalFriendship::FillBuffer(
-          this->Parser, cp, ep);
-    r &= (n <= static_cast<size_t>(ep - cp));
+    r = vtkDICOMParserInternalFriendship::FillBuffer(this->Parser, cp, ep);
+    if (r && n > static_cast<size_t>(ep - cp))
+    {
+      cp = ep;
+      r = false;
+    }
   }
   return r;
 }
@@ -666,9 +680,12 @@ inline bool DecoderBase::CheckBuffer(
   if (n > static_cast<size_t>(ep - cp))
   {
     this->CopyBuffer(v, sp, cp);
-    r = vtkDICOMParserInternalFriendship::FillBuffer(
-          this->Parser, cp, ep);
-    r &= (n <= static_cast<size_t>(ep - cp));
+    r = vtkDICOMParserInternalFriendship::FillBuffer(this->Parser, cp, ep);
+    if (r && n > static_cast<size_t>(ep - cp))
+    {
+      cp = ep;
+      r = false;
+    }
     sp = cp;
   }
   return r;
@@ -920,6 +937,48 @@ bool DecoderBase::FinishQuery()
   return this->QueryMatched;
 }
 
+//----------------------------------------------------------------------------
+void DecoderBase::ParseError(
+  const unsigned char *cp, const unsigned char *ep, const char *message)
+{
+  vtkDICOMTag tag = this->LastTag;
+  const char *name = "Element";
+
+  vtkDICOMDictEntry de = vtkDICOMDictionary::FindDictEntry(tag);
+  if (de.IsValid())
+  {
+    name = de.GetName();
+  }
+
+  std::stringstream msg;
+  msg << "In " << name << " " << tag;
+
+  int idx = this->Context->GetIndex();
+  for (DecoderContext *context = this->Context->GetPrev();
+       context; context = context->GetPrev())
+  {
+    tag = context->GetCurrentTag();
+    name = "Sequence";
+
+    de = vtkDICOMDictionary::FindDictEntry(tag);
+    if (de.IsValid())
+    {
+      name = de.GetName();
+    }
+    msg << ", in " << name << " " << tag;
+    if (idx >= 0)
+    {
+      msg << " [Item " << (idx + 1) << "]";
+    }
+    idx = context->GetIndex();
+  }
+
+  msg << ": " << message;
+
+  vtkDICOMParserInternalFriendship::ParseError(
+    this->Parser, cp, ep, msg.str().c_str());
+}
+
 //----------------------------------------------------------------------------
 template<>
 inline unsigned short Decoder<LE>::GetInt16(const unsigned char *ip)
@@ -1163,8 +1222,7 @@ size_t Decoder<E>::ReadElementHead(
       // check that buffer has 4 bytes for 32-bit VL
       if (!this->CheckBuffer(cp, ep, 4))
       {
-        vtkDICOMParserInternalFriendship::ParseError(this->Parser, cp, ep,
-          "Unexpected end of file.");
+        this->ParseError(cp, ep, "Unexpected end of file.");
         return 0;
       }
       vl = Decoder<E>::GetInt32(cp);
@@ -1196,35 +1254,39 @@ size_t Decoder<E>::ReadElementValue(
         cp, ep, vl, vtkDICOMTag(HxFFFE,HxE0DD), &v);
       return v.GetNumberOfValues();
     }
-    else if (vr == vtkDICOMVR::OB)
+    else if (vr == vtkDICOMVR::OB || vr == vtkDICOMVR::OW)
     {
-      // make sure unknown length data is properly encapsulated
+      // note that OW should not contain encapsulated data, but
+      // we tolerate it here and convert the VR to OB
       if (!this->CheckBuffer(cp, ep, 8))
       {
-        vtkDICOMParserInternalFriendship::ParseError(this->Parser, cp, ep,
-          "Unexpected end of file.");
+        this->ParseError(cp, ep, "Unexpected end of file.");
         return 0;
       }
       unsigned short g1 = Decoder<E>::GetInt16(cp);
       unsigned short e1 = Decoder<E>::GetInt16(cp + 2);
       if (g1 != HxFFFE || (e1 != HxE000 && e1 != HxE0DD))
       {
-        vtkDICOMParserInternalFriendship::ParseError(this->Parser, cp, ep,
+        this->ParseError(cp, ep,
           "Encapsulated object is missing (FFFE,E000) tag.");
         return 0;
       }
 
-      v.AllocateUnsignedCharData(vr, 0);
+      v.AllocateUnsignedCharData(vtkDICOMVR::OB, 0);
       this->SkipElements(
         cp, ep, vl, vtkDICOMTag(HxFFFE,HxE0DD), &v);
       return v.GetNumberOfValues();
     }
     else if (vr != vtkDICOMVR::SQ)
     {
-      // only UN, OB, and SQ can have unknown length
-      vtkDICOMParserInternalFriendship::ParseError(this->Parser, cp, ep,
-        "Illegal item length FFFFFFFF encountered.");
-      return 0;
+      // only UN, OB, and SQ can have unknown length, but rather than fail,
+      // we attempt to skip this element in case we can read the rest
+      v.AllocateUnsignedCharData(vtkDICOMVR::OB, 0);
+      this->SkipElements(
+        cp, ep, vl, vtkDICOMTag(HxFFFE,HxE0DD), &v);
+      l = v.GetNumberOfValues();
+      v = vtkDICOMValue(vr);
+      return l;
     }
   }
   else if (static_cast<size_t>(ep - cp) < static_cast<size_t>(vl))
@@ -1236,7 +1298,7 @@ size_t Decoder<E>::ReadElementValue(
           this->Parser, cp, ep);
     if (static_cast<vtkTypeInt64>(vl) > bytesRemaining)
     {
-      vtkDICOMParserInternalFriendship::ParseError(this->Parser, cp, ep,
+      this->ParseError(cp, ep,
         "Item length exceeds the bytes remaining in file.");
       return 0;
     }
@@ -2249,8 +2311,7 @@ bool vtkDICOMParser::ReadMetaData(
       if ((vl != 0xFFFFFFFF && r < static_cast<vtkTypeInt64>(vl)) ||
           !this->SkipValue(cp, ep, vl))
       {
-        this->ParseError(cp, ep,
-          "Premature end of file while reading PixelData.");
+        vtkErrorMacro("Premature end of file while reading PixelData.");
         readFailure = true;
       }
     }
@@ -2393,8 +2454,8 @@ void vtkDICOMParser::ParseError(
 {
   this->FileOffset = this->GetBytesProcessed(cp, ep);
   this->SetErrorCode(vtkErrorCode::FileFormatError);
-  vtkErrorMacro("At byte offset " << this->FileOffset << " in file "
-                << this->FileName << ": " << message);
+  vtkErrorMacro("At byte offset " << this->FileOffset << " in file \""
+                << this->FileName << "\": " << message);
 }
 
 //----------------------------------------------------------------------------
