@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -27,11 +27,21 @@
 #include "vtkDICOMConfig.h" // For configuration details
 #include "vtkDICOMCharacterSet.h" // For character sets
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkIntArray;
 class vtkTypeInt64Array;
 class vtkStringArray;
 class vtkMatrix4x4;
 class vtkMedicalImageProperties;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkDICOMMetaData;
 class vtkDICOMParser;
 class vtkDICOMSliceSorter;
@@ -315,7 +325,7 @@ public:
 
 protected:
   vtkDICOMReader();
-  ~vtkDICOMReader();
+  ~vtkDICOMReader() VTK_DICOM_OVERRIDE;
 
   //@{
   //! Entry point for all pipeline requests.
