@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -49,7 +49,7 @@ public:
 
 protected:
   vtkDICOMSCGenerator();
-  ~vtkDICOMSCGenerator();
+  ~vtkDICOMSCGenerator() VTK_DICOM_OVERRIDE;
 
   //! Generate the SC Equipment Module.
   virtual bool GenerateSCEquipmentModule(vtkDICOMMetaData *source);
