@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -19,8 +19,18 @@
 #include "vtkDICOMConfig.h" // For configuration details
 #include "vtkDICOMTag.h" // For vtkDICOMTag
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkIntArray;
 class vtkStringArray;
+
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 class vtkDICOMMetaData;
 
 //! Index a DICOM series to allow proper dimensional ordering.
@@ -150,7 +160,7 @@ public:
    *  This is only used for enhanced multi-frame images.  If used, then
    *  SetTimeTag() must also be used to specify which tag in the sequence
    *  to use for temporal sorting.  By default, the following sequence/tag
-   *  conbinations are automatically detected and applied:
+   *  combinations are automatically detected and applied:
    *  - CardiacSynchronizationSequence/NominalCardiacTriggerDelayTime
    *  - TemporalPositionSequence/TemporalPositionTimeOffset
    *  - FrameContentSequence/TemporalPositionIndex
@@ -181,7 +191,7 @@ public:
 
 protected:
   vtkDICOMSliceSorter();
-  ~vtkDICOMSliceSorter();
+  ~vtkDICOMSliceSorter() VTK_DICOM_OVERRIDE;
 
   // Sort the input files, put the sort in the supplied arrays.
   virtual void SortFiles(vtkIntArray *fileArray, vtkIntArray *frameArray);
