@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -31,8 +31,17 @@
 #include "vtkDICOMModule.h" // For export macro
 #include "vtkDICOMConfig.h" // For configuration details
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkMatrix4x4;
 
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 //----------------------------------------------------------------------------
 class VTKDICOM_EXPORT vtkDICOMToRAS : public vtkThreadedImageAlgorithm
 {
@@ -85,7 +94,7 @@ public:
   //@}
 
   //@{
-  //! Set whether the RAS matrix should hava a non-zero final column.
+  //! Set whether the RAS matrix should have a non-zero final column.
   /*!
    *  By default, the RAS matrix produced by this filter will have a
    *  position coordinate in its final column (NIfTI style).
@@ -133,7 +142,7 @@ public:
 
 protected:
   vtkDICOMToRAS();
-  ~vtkDICOMToRAS();
+  ~vtkDICOMToRAS() VTK_DICOM_OVERRIDE;
 
   //! Check whether the data will be reordered in cols or rows.
   void CheckNeedToReorder();
