@@ -2,7 +2,7 @@
 
   Program: DICOM for VTK
 
-  Copyright (c) 2012-2019 David Gobbi
+  Copyright (c) 2012-2022 David Gobbi
   All rights reserved.
   See Copyright.txt or http://dgobbi.github.io/bsd3.txt for details.
 
@@ -20,8 +20,17 @@
 #include "vtkDICOMConfig.h" // For configuration details
 #include "vtkDICOMTag.h" // For method parameter
 
+// Declare VTK classes within VTK's optional namespace
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_BEGIN
+#endif
+
 class vtkStringArray;
 
+#if defined(VTK_ABI_NAMESPACE_BEGIN)
+VTK_ABI_NAMESPACE_END
+#endif
+
 //! Utility functions for use with DICOM classes.
 class VTKDICOM_EXPORT vtkDICOMUtilities : public vtkObject
 {
@@ -198,7 +207,7 @@ public:
 
 protected:
   vtkDICOMUtilities() {}
-  ~vtkDICOMUtilities() {}
+  ~vtkDICOMUtilities() VTK_DICOM_OVERRIDE {}
 
   static long long GetLocalOffset(long long t);
 
