@@ -317,7 +317,7 @@ int vtkNIFTIReader::CanReadFile(const char *filename)
     return 0;
   }
 
-#if _WIN32
+#ifdef _WIN32
   vtkDICOMFilePath fp(hdrname);
 #if VTK_MAJOR_VERSION < 7
   // convert to the local character set
@@ -439,7 +439,7 @@ int vtkNIFTIReader::RequestInformation(
 
   vtkDebugMacro("Opening NIFTI file " << hdrname);
 
-#if _WIN32
+#ifdef _WIN32
   vtkDICOMFilePath fph(hdrname);
 #if VTK_MAJOR_VERSION < 7
   // convert to the local character set
@@ -784,7 +784,7 @@ int vtkNIFTIReader::RequestInformation(
   //    offset when R is the identity matrix.
   //
   // 3) If there is a qform and qfac is -1, then the situation is more
-  //    compilcated.  We have three choices, each of which is a compromise:
+  //    complicated.  We have three choices, each of which is a compromise:
   //    a) we can use Spacing[2] = qfac*pixdim[3], i.e. use a negative
   //       slice spacing, which might cause some VTK algorithms to
   //       misbehave (the VTK tests only use images with positive spacing).
@@ -1041,11 +1041,7 @@ int vtkNIFTIReader::RequestData(
   // get the data object, allocate memory
   vtkImageData *data =
     static_cast<vtkImageData *>(outInfo->Get(vtkDataObject::DATA_OBJECT()));
-#if VTK_MAJOR_VERSION >= 6
   this->AllocateOutputData(data, outInfo, extent);
-#else
-  this->AllocateOutputData(data, extent);
-#endif
 
   data->GetPointData()->GetScalars()->SetName("NIFTI");
 
@@ -1105,7 +1101,7 @@ int vtkNIFTIReader::RequestData(
   unsigned char *dataPtr =
     static_cast<unsigned char *>(data->GetScalarPointer());
 
-#if _WIN32
+#ifdef _WIN32
   vtkDICOMFilePath fpi(imgname);
 #if VTK_MAJOR_VERSION < 7
   // convert to the local character set
