@@ -31,8 +31,10 @@
 #endif
 
 #include <ctype.h>
+#include <math.h>
 #include <stdlib.h>
 #include <string.h>
+#include <iostream>
 #include <string>
 #include <sstream>
 #include <locale>
@@ -176,7 +178,13 @@ int vtkScancoCTReader::CheckVersion(const char header[16])
 //----------------------------------------------------------------------------
 int vtkScancoCTReader::CanReadFile(const char *filename)
 {
-  ifstream infile(filename, ios::in | ios::binary);
+#if defined(_WIN32) && (_MSC_VER >= 1400)
+  vtkDICOMFilePath fp(filename);
+  const wchar_t *ufilename = fp.Wide();
+#else
+  const char *ufilename = filename;
+#endif
+  std::ifstream infile(ufilename, ios::in | ios::binary);
 
   bool canRead = false;
   if (infile.good())
@@ -409,7 +417,7 @@ void vtkScancoCTReader::StripString(char *dest, const char *cp, size_t l)
 }
 
 //----------------------------------------------------------------------------
-int vtkScancoCTReader::ReadISQHeader(ifstream *file, unsigned long bytesRead)
+int vtkScancoCTReader::ReadISQHeader(std::istream *file, unsigned long bytesRead)
 {
   if (bytesRead < 512)
   {
@@ -620,7 +628,7 @@ int vtkScancoCTReader::ReadISQHeader(ifstream *file, unsigned long bytesRead)
 }
 
 //----------------------------------------------------------------------------
-int vtkScancoCTReader::ReadAIMHeader(ifstream *file, unsigned long bytesRead)
+int vtkScancoCTReader::ReadAIMHeader(std::istream *file, unsigned long bytesRead)
 {
   if (bytesRead < 160)
   {
@@ -987,7 +995,7 @@ int vtkScancoCTReader::RequestInformation(
   const char *ufilename = filename;
 #endif
 
-  ifstream infile(ufilename, ios::in | ios::binary);
+  std::ifstream infile(ufilename, ios::in | ios::binary);
   if (!infile.good())
   {
     vtkErrorMacro("Cannot open file " << filename);
@@ -1086,11 +1094,7 @@ int vtkScancoCTReader::RequestData(
   // get the data object, allocate memory
   vtkImageData *data =
     static_cast<vtkImageData *>(outInfo->Get(vtkDataObject::DATA_OBJECT()));
-#if VTK_MAJOR_VERSION >= 6
   this->AllocateOutputData(data, outInfo, extent);
-#else
-  this->AllocateOutputData(data, extent);
-#endif
 
   data->GetPointData()->GetScalars()->SetName("ImageFile");
 
@@ -1114,8 +1118,16 @@ int vtkScancoCTReader::RequestData(
   unsigned char *dataPtr =
     static_cast<unsigned char *>(data->GetScalarPointer());
 
+  // convert utf-8 to wide string for Windows
+#if defined(_WIN32) && (_MSC_VER >= 1400)
+  vtkDICOMFilePath fp(filename);
+  const wchar_t *ufilename = fp.Wide();
+#else
+  const char *ufilename = filename;
+#endif
+
   // open the file
-  ifstream infile(filename, ios::in | ios::binary);
+  std::ifstream infile(ufilename, ios::in | ios::binary);
   if (!infile.good())
   {
     vtkErrorMacro("Cannot open file " << filename);
