@@ -20,11 +20,7 @@ if (!(t)) \
   rval |= 1; \
 }
 
-#ifdef VTK_IN_VTK
 int TestDICOMMetaData(int argc, char *argv[])
-#else
-int main(int argc, char *argv[])
-#endif
 {
   int rval = 0;
   const char *exename = (argc > 0 ? argv[0] : "TestDICOMMetaData");
@@ -570,3 +566,10 @@ int main(int argc, char *argv[])
 
   return rval;
 }
+
+#ifdef VTK_DICOM_SEPARATE_TESTS
+int main(int argc, char *argv[])
+{
+  return TestDICOMMetaData(argc, argv);
+}
+#endif
