@@ -36,11 +36,7 @@ bool StringsEqual(const char *s1, const char *s2)
 
 }
 
-#ifdef VTK_IN_VTK
 int TestDICOMSequence(int argc, char *argv[])
-#else
-int main(int argc, char *argv[])
-#endif
 {
   int rval = 0;
   const char *exename = (argc > 0 ? argv[0] : "TestDICOMSequence");
@@ -210,3 +206,10 @@ int main(int argc, char *argv[])
 
   return rval;
 }
+
+#ifdef VTK_DICOM_SEPARATE_TESTS
+int main(int argc, char *argv[])
+{
+  return TestDICOMSequence(argc, argv);
+}
+#endif
